@@ -100,10 +100,12 @@ class ContainerLauncher:
                 'status': RunStatus.INITIALIZING.name
             })
 
-            is_spot = container_input.get('is_spot', True)
+            is_spot = container_input.get('is_spot', False)
 
             usage_class = 'spot' if is_spot else 'on-demand'
 
+            storages = container_input.get('storages')
+
             if container_input.get('instance_type'):
                 instance_type = container_input['instance_type']
             else:
@@ -136,7 +138,7 @@ class ContainerLauncher:
             self.__create_launch_template({
                 'ami': ami,
                 'instance_type': instance_type,
-                'storage': container_input.get('storage'),
+                'storages': storages,
                 'is_spot': is_spot,
                 'ec2_sg_id': ec2_sg_id
             })
@@ -928,16 +930,35 @@ class ContainerLauncher:
         ecs_cluster_name = f'{self.__name_prefix}-ecs-cluster-{name_suffix}'
         instance_profile_arn = self.__resources['instance_profile_arn']
         launch_template_name = f'{self.__name_prefix}-launch-config-{name_suffix}'
-        storage = launch_template_opts.get('storage')
         user_data = launch_template_opts.get('user_data', '')
         instance_type = launch_template_opts['instance_type']
         ec2_sg_id = launch_template_opts['ec2_sg_id']
-        is_spot = False if launch_template_opts.get('is_spot') is not None and launch_template_opts[
-            'is_spot'] == False else True
+        is_spot = launch_template_opts.get('is_spot', False)
+        storages = launch_template_opts.get('storages')
 
         install_ecs_agent_cmd = f'echo ECS_CLUSTER={ecs_cluster_name} >> /etc/ecs/ecs.config;echo ECS_BACKEND_HOST= >> /etc/ecs/ecs.config;'
-        if storage:
-            if storage['type'] == 'fsx':
+        if storages is not None:
+            ssd_instance_stores = [storage for storage in storages if storage['type'] == 'ssd_instance_store']
+            if len(ssd_instance_stores) > 0:
+                mount_ssd_instance_store_command = '''yum install mdadm -y
+yum install jq -y
+mounts=($(lsblk --fs --json | jq -r '.blockdevices[] | select(.children == null and .fstype == null) | .name'))
+for i in "${mounts[@]}" ; do echo -e "o\\nn\\np\\n1\\n\\n\\nw" | fdisk /dev/$i ; done
+dev_mounts=""
+for i in "${mounts[@]}" ; do dev_mounts="$dev_mounts /dev/$i" ; done
+echo $dev_mounts >> /etc/ecs/dev_mount_file.out
+echo -e "o\\ny" | mdadm --create --verbose --force --auto=yes /dev/md0 --level=0 --raid-devices=2 $dev_mounts >> /etc/ecs/dev_mount.out
+mkfs.ext4 /dev/md0
+mkdir /ssd
+echo /dev/md0 /ssd ext4 defaults 0 0 >> /etc/fstab
+mount /dev/md0 /ssd
+                '''
+                user_data = f'{user_data}\n{mount_ssd_instance_store_command}'
+
+            fsx_storages = [storage for storage in storages if storage['type'] == 'fsx']
+            if len(fsx_storages) > 0:
+                # TODO Add support of multiple FSx storages
+                storage = fsx_storages[0]
                 file_system_id = storage['file_system_id']
                 fsx_dir = storage.get('dir', '/fsx')
                 fsx = Fsx({'region': self.__region})
@@ -946,7 +967,8 @@ class ContainerLauncher:
                 mount_name = file_system['LustreConfiguration']['MountName']
                 install_fsx_agent_cmd = 'amazon-linux-extras install -y lustre2.10'
                 user_data = f'{user_data}\n{install_fsx_agent_cmd}\nmkdir {fsx_dir}\nmount -t lustre -o noatime,flock {dns_name}@tcp:/{mount_name} {fsx_dir}'
-        user_data = f'#!/bin/bash\n{install_ecs_agent_cmd}\n\n{user_data}'
+        output_logs_command = 'exec > >(tee /var/log/user-data.log|logger -t user-data -s 2>/dev/console) 2>&1'
+        user_data = f'#!/bin/bash\n{install_ecs_agent_cmd}\n{output_logs_command}\n{user_data}'
 
         self.logger.debug(f'The EC2 user data: {user_data}')
 
